function [s1,s2,thp,tau,thsl] = principal_stress(sxx,syy,sxy)
% principal_stress -- calculates principal stress (in 2D) from components. 
%
% Author: Agnieszka Herman, IOUG (agnieszka.herman@ug.edu.pl)
%
% Input:
%   sxx - normal stress in the x direction
%   syy - normal stress in the y direction
%   sxy - shear stress
% Output:
%   s1   - maximum normal stress
%   s2   - minimum normal stress
%   thp  - principal angle
%   tau  - maximum shear stress
%   thsl - maximum shear angle
%
thp = atan(2*sxy./(sxx-syy))/2;
tmp = sqrt(((sxx-syy)/2).^2 + sxy.^2);
s1tmp = (sxx+syy)/2 + tmp;
s2tmp = (sxx+syy)/2 - tmp;
s1 = max(s1tmp,s2tmp);
s2 = min(s1tmp,s2tmp);
tau = (s1-s2)/2;
thsl = atan(-(sxx-syy)./(2*sxy))/2;